biom.table.Table._extract_data_from_tsv — biom-format.org

# biom-format.org

## biom.table.Table._extract_data_from_tsv

static `Table.` `_extract_data_from_tsv`(lines, delim='\t', dtype=<type 'float'>, md_parse=None)

  Parse a classic table into (sample_ids, obs_ids, data, metadata, name)

  Parameters: | lines: list or file-like object delimted data to parse delim: string delimeter in file lines dtype: type md_parse: function or None funtion used to parse metdata
  Returns: | list sample_ids list observation_ids array data list metadata string column name if last column is non-numeric

  Notes

  This is intended to be close to how QIIME classic OTU tables are parsed with the exception of the additional md_name field

  This function is ported from QIIME (http://www.qiime.org), previously named parse_classic_otu_table. QIIME is a GPL project, but we obtained permission from the authors of this function to port it to the BIOM Format project (and keep it under BIOM’s BSD license).